#[repr(C)]pub struct ViewCreationToken {
pub value: Channel,
}Expand description
Two Flatland instances may be connected in a parent-child relationship. The child endpoint is held in a View. This view is strongly associated with a ViewRef and other related protocols.
ViewCreationToken is a typed wrapper for a channel, representing the child endpoint of the connection between two Flatland instances. No messages will be sent over this channel, because it is only used as an unclonable object with peer.
Fields
value: ChannelTrait Implementations
Sourceimpl Debug for ViewCreationToken
impl Debug for ViewCreationToken
Sourceimpl<___E> Encode<ViewCreationToken, ___E> for ViewCreationTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ViewCreationToken, ___E> for ViewCreationTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ViewCreationToken>
const COPY_OPTIMIZATION: CopyOptimization<Self, ViewCreationToken>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewCreationToken>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewCreationToken>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ViewCreationToken>, ___E> for ViewCreationToken
impl<___E> EncodeOption<Box<'static, ViewCreationToken>, ___E> for ViewCreationToken
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ViewCreationToken>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ViewCreationToken>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ViewCreationToken> for ViewCreationToken
impl FromWire<ViewCreationToken> for ViewCreationToken
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ViewCreationToken, Self>
const COPY_OPTIMIZATION: CopyOptimization<ViewCreationToken, Self>
Sourcefn from_wire(wire: ViewCreationToken) -> Self
fn from_wire(wire: ViewCreationToken) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ViewCreationToken
impl PartialEq for ViewCreationToken
impl StructuralPartialEq for ViewCreationToken