#[repr(C)]pub struct ViewHolderToken {
pub value: EventPair,
}Expand description
Token that uniquely identifies an attachment point for a View in the
global scene graph. Each ViewHolderToken has exactly one corresponding
ViewToken.
A Scenic client can reference contents from another client by creating a
ViewHolder resource using this token. The other client must also create
a View resource using the corresponding ViewToken.
Fields
value: EventPairTrait Implementations
Sourceimpl Debug for ViewHolderToken
impl Debug for ViewHolderToken
Sourceimpl<___E> Encode<ViewHolderToken, ___E> for ViewHolderTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ViewHolderToken, ___E> for ViewHolderTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ViewHolderToken>
const COPY_OPTIMIZATION: CopyOptimization<Self, ViewHolderToken>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewHolderToken>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewHolderToken>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ViewHolderToken>, ___E> for ViewHolderToken
impl<___E> EncodeOption<Box<'static, ViewHolderToken>, ___E> for ViewHolderToken
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ViewHolderToken>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ViewHolderToken>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ViewHolderToken> for ViewHolderToken
impl FromWire<ViewHolderToken> for ViewHolderToken
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ViewHolderToken, Self>
const COPY_OPTIMIZATION: CopyOptimization<ViewHolderToken, Self>
Sourcefn from_wire(wire: ViewHolderToken) -> Self
fn from_wire(wire: ViewHolderToken) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ViewHolderToken
impl PartialEq for ViewHolderToken
impl StructuralPartialEq for ViewHolderToken