#[repr(C)]pub struct ViewRefControl {
pub reference: EventPair,
}Expand description
A ViewRefControl is the peer to a ViewRef. Their references are linked.
Like ViewRef, a ViewRefControl is a typed handle to an eventpair. Unlike
ViewRef, a ViewRefControl’s handle is unique. Scenic uses this property
when it ties a ViewRefControl to a View, arranged to share fate. When a
View is destroyed, the associated destruction of its ViewRefControl
triggers an automatic ZX_EVENTPAIR_PEER_CLOSED signal sent to all ViewRef
holders; hence ViewRef holders may track View lifetime.
As part of View creation, the client creates a linked ViewRef/ViewRefControl pair and hands the pair to Scenic (ViewRef is described above). The client must not clone the ViewRefControl. It must not remove or modify the ViewRefControl’s capabilities; otherwise the View is not created.
Fields
reference: EventPairTrait Implementations
Sourceimpl Debug for ViewRefControl
impl Debug for ViewRefControl
Sourceimpl<___E> Encode<ViewRefControl, ___E> for ViewRefControlwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ViewRefControl, ___E> for ViewRefControlwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ViewRefControl>
const COPY_OPTIMIZATION: CopyOptimization<Self, ViewRefControl>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewRefControl>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewRefControl>, _: (), ) -> Result<(), EncodeError>
Sourceimpl<___E> EncodeOption<Box<'static, ViewRefControl>, ___E> for ViewRefControl
impl<___E> EncodeOption<Box<'static, ViewRefControl>, ___E> for ViewRefControl
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ViewRefControl>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ViewRefControl>>, _: (), ) -> Result<(), EncodeError>
Sourceimpl FromWire<ViewRefControl> for ViewRefControl
impl FromWire<ViewRefControl> for ViewRefControl
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ViewRefControl, Self>
const COPY_OPTIMIZATION: CopyOptimization<ViewRefControl, Self>
Sourcefn from_wire(wire: ViewRefControl) -> Self
fn from_wire(wire: ViewRefControl) -> Self
Sourceimpl PartialEq for ViewRefControl
impl PartialEq for ViewRefControl
impl StructuralPartialEq for ViewRefControl