#[repr(C)]pub struct ViewToken {
pub value: EventPair,
}Expand description
Token that uniquely identifies a View, which is the root point for a
subgraph in the global scene graph. Each ViewToken has exactly one
corresponding ViewHolderToken.
A Scenic client can have its contents referenced from another client by
creating a View resource using this token. The other client must also
create a ViewHolder resource using the corresponding ViewHolderToken.
Fields
value: EventPairTrait Implementations
Sourceimpl<___E> Encode<ViewToken, ___E> for ViewTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ViewToken, ___E> for ViewTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ViewToken>
const COPY_OPTIMIZATION: CopyOptimization<Self, ViewToken>
Sourceimpl<___E> EncodeOption<Box<'static, ViewToken>, ___E> for ViewToken
impl<___E> EncodeOption<Box<'static, ViewToken>, ___E> for ViewToken
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ViewToken>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ViewToken>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl StructuralPartialEq for ViewToken