ViewportCreationToken

Struct ViewportCreationToken 

#[repr(C)]
pub struct ViewportCreationToken { pub value: Channel, }
Two Flatland instances may be connected in a parent-child relationship. The parent endpoint is held in a Viewport.

ViewportCreationToken is a typed wrapper for a channel, representing the parent endpoint of the connection between two Flatlands. No messages will be sent over this channel, because it is only used as an unclonable object with peer.

Fields

value: Channel