pub trait ViewRefFocusedLocalServerHandler<___T = Channel>where
___T: Transport,{
// Required method
fn watch(
&mut self,
responder: Responder<Watch, ___T>,
) -> impl Future<Output = ()>;
}Expand description
A server handler for the ViewRefFocused protocol.
See ViewRefFocused for more details.
Required Methods
Sourcefn watch(
&mut self,
responder: Responder<Watch, ___T>,
) -> impl Future<Output = ()>
fn watch( &mut self, responder: Responder<Watch, ___T>, ) -> impl Future<Output = ()>
Sets up a callback to fire when the implicit ViewRef has gained or lost focus. Typically, focus changes happen at a slow pace, such that every transition is captured by the callback. However, focus changes can happen rapidly, so the callback may “compress” focus change history into just the latest known focus state.
The callback reports the last focus change spanning the duration from its issuance to the previous callback’s issuance. The client may observe any of the following four transitions:
- true -> true: The ViewRef has lost focus at least once, and has gained focus by the time of callback issuance.
- true -> false: The ViewRef has lost focus at least once, and has lost focus by the time of callback issuance.
- false -> true: The ViewRef has gained focus at least once, and has gained focus by the time of callback issuance.
- false -> false: The ViewRef has gained focus at least once, and has lost focus by the time of callback issuance.
The client avoids “focus flapping” and always sees the latest state. Every callback issuance is meaningful, and the client should renegotiate focus-related services appropriately, such as IME.
Flow control: The caller is allowed at most one in-flight |Watch| call at at time: subsequent |Watch| calls must wait until the acknowledgment returns. Non-compliance results in channel closure.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.