#[repr(C)]pub struct FocuserRequestFocusRequest {
pub view_ref: ViewRef,
}Expand description
The wire type corresponding to FocuserRequestFocusRequest.
Fields
view_ref: ViewRefTrait Implementations
Sourceimpl Constrained for FocuserRequestFocusRequest
impl Constrained for FocuserRequestFocusRequest
Sourceimpl Debug for FocuserRequestFocusRequest
impl Debug for FocuserRequestFocusRequest
Sourceimpl<___D> Decode<___D> for FocuserRequestFocusRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for FocuserRequestFocusRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<FocuserRequestFocusRequest, ___E> for FocuserRequestFocusRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<FocuserRequestFocusRequest, ___E> for FocuserRequestFocusRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, FocuserRequestFocusRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, FocuserRequestFocusRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FocuserRequestFocusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FocuserRequestFocusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<FocuserRequestFocusRequest, ___E> for FocuserRequestFocusRequest<T0>
impl<___E, T0> Encode<FocuserRequestFocusRequest, ___E> for FocuserRequestFocusRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FocuserRequestFocusRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FocuserRequestFocusRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<FocuserRequestFocusRequest> for FocuserRequestFocusRequest
impl FromWire<FocuserRequestFocusRequest> for FocuserRequestFocusRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<FocuserRequestFocusRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<FocuserRequestFocusRequest, Self>
Sourcefn from_wire(wire: FocuserRequestFocusRequest) -> Self
fn from_wire(wire: FocuserRequestFocusRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for FocuserRequestFocusRequest
impl IntoNatural for FocuserRequestFocusRequest
Sourcetype Natural = FocuserRequestFocusRequest
type Natural = FocuserRequestFocusRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for FocuserRequestFocusRequest
impl Wire for FocuserRequestFocusRequest
Sourcetype Narrowed<'de> = FocuserRequestFocusRequest
type Narrowed<'de> = FocuserRequestFocusRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.