#[repr(C)]pub struct ViewCreationToken {
pub value: Channel,
}Expand description
The wire type corresponding to ViewCreationToken.
Fields
value: ChannelTrait Implementations
Sourceimpl Constrained for ViewCreationToken
impl Constrained for ViewCreationToken
Sourceimpl Debug for ViewCreationToken
impl Debug for ViewCreationToken
Sourceimpl<___D> Decode<___D> for ViewCreationTokenwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ViewCreationTokenwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ViewCreationToken, ___E> for ViewCreationTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ViewCreationToken, ___E> for ViewCreationTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ViewCreationToken>
const COPY_OPTIMIZATION: CopyOptimization<Self, ViewCreationToken>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewCreationToken>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewCreationToken>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ViewCreationToken, ___E> for ViewCreationToken<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Channel, ___E>,
impl<___E, T0> Encode<ViewCreationToken, ___E> for ViewCreationToken<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Channel, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewCreationToken>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewCreationToken>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ViewCreationToken> for ViewCreationToken
impl FromWire<ViewCreationToken> for ViewCreationToken
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ViewCreationToken, Self>
const COPY_OPTIMIZATION: CopyOptimization<ViewCreationToken, Self>
Sourcefn from_wire(wire: ViewCreationToken) -> Self
fn from_wire(wire: ViewCreationToken) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ViewCreationToken
impl IntoNatural for ViewCreationToken
Sourcetype Natural = ViewCreationToken
type Natural = ViewCreationToken
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ViewCreationToken
impl Wire for ViewCreationToken
Sourcetype Narrowed<'de> = ViewCreationToken
type Narrowed<'de> = ViewCreationToken
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.