#[repr(C)]pub struct ViewIdentityOnCreation {
pub view_ref: ViewRef,
pub view_ref_control: ViewRefControl,
}Expand description
The wire type corresponding to ViewIdentityOnCreation.
Fields
view_ref: ViewRefview_ref_control: ViewRefControlTrait Implementations
Sourceimpl Constrained for ViewIdentityOnCreation
impl Constrained for ViewIdentityOnCreation
Sourceimpl Debug for ViewIdentityOnCreation
impl Debug for ViewIdentityOnCreation
Sourceimpl<___D> Decode<___D> for ViewIdentityOnCreationwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ViewIdentityOnCreationwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ViewIdentityOnCreation, ___E> for ViewIdentityOnCreationwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ViewIdentityOnCreation, ___E> for ViewIdentityOnCreationwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ViewIdentityOnCreation>
const COPY_OPTIMIZATION: CopyOptimization<Self, ViewIdentityOnCreation>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewIdentityOnCreation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewIdentityOnCreation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<ViewIdentityOnCreation, ___E> for ViewIdentityOnCreation<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<ViewRef, ___E>,
T1: Encode<ViewRefControl, ___E>,
impl<___E, T0, T1> Encode<ViewIdentityOnCreation, ___E> for ViewIdentityOnCreation<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<ViewRef, ___E>,
T1: Encode<ViewRefControl, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewIdentityOnCreation>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewIdentityOnCreation>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ViewIdentityOnCreation> for ViewIdentityOnCreation
impl FromWire<ViewIdentityOnCreation> for ViewIdentityOnCreation
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ViewIdentityOnCreation, Self>
const COPY_OPTIMIZATION: CopyOptimization<ViewIdentityOnCreation, Self>
Sourcefn from_wire(wire: ViewIdentityOnCreation) -> Self
fn from_wire(wire: ViewIdentityOnCreation) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ViewIdentityOnCreation
impl IntoNatural for ViewIdentityOnCreation
Sourcetype Natural = ViewIdentityOnCreation
type Natural = ViewIdentityOnCreation
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ViewIdentityOnCreation
impl Wire for ViewIdentityOnCreation
Sourcetype Narrowed<'de> = ViewIdentityOnCreation
type Narrowed<'de> = ViewIdentityOnCreation
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.