#[repr(C)]pub struct ViewPresentRequest {
pub view_token: ViewToken,
}Expand description
The wire type corresponding to ViewPresentRequest.
Fields
view_token: ViewTokenTrait Implementations
Sourceimpl Constrained for ViewPresentRequest
impl Constrained for ViewPresentRequest
Sourceimpl Debug for ViewPresentRequest
impl Debug for ViewPresentRequest
Sourceimpl<___D> Decode<___D> for ViewPresentRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ViewPresentRequestwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ViewPresentRequest, ___E> for ViewPresentRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ViewPresentRequest, ___E> for ViewPresentRequestwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ViewPresentRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, ViewPresentRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewPresentRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewPresentRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ViewPresentRequest, ___E> for ViewPresentRequest<T0>
impl<___E, T0> Encode<ViewPresentRequest, ___E> for ViewPresentRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewPresentRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewPresentRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ViewPresentRequest> for ViewPresentRequest
impl FromWire<ViewPresentRequest> for ViewPresentRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ViewPresentRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<ViewPresentRequest, Self>
Sourcefn from_wire(wire: ViewPresentRequest) -> Self
fn from_wire(wire: ViewPresentRequest) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ViewPresentRequest
impl IntoNatural for ViewPresentRequest
Sourcetype Natural = ViewPresentRequest
type Natural = ViewPresentRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ViewPresentRequest
impl Wire for ViewPresentRequest
Sourcetype Narrowed<'de> = ViewPresentRequest
type Narrowed<'de> = ViewPresentRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.