#[repr(C)]pub struct ViewRefControl {
pub reference: EventPair,
}Expand description
The wire type corresponding to ViewRefControl.
Fields
reference: EventPairTrait Implementations
Sourceimpl Constrained for ViewRefControl
impl Constrained for ViewRefControl
Sourceimpl Debug for ViewRefControl
impl Debug for ViewRefControl
Sourceimpl<___D> Decode<___D> for ViewRefControlwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ViewRefControlwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ViewRefControl, ___E> for ViewRefControlwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ViewRefControl, ___E> for ViewRefControlwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ViewRefControl>
const COPY_OPTIMIZATION: CopyOptimization<Self, ViewRefControl>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewRefControl>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewRefControl>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ViewRefControl, ___E> for ViewRefControl<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
impl<___E, T0> Encode<ViewRefControl, ___E> for ViewRefControl<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<EventPair, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewRefControl>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewRefControl>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ViewRefControl> for ViewRefControl
impl FromWire<ViewRefControl> for ViewRefControl
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ViewRefControl, Self>
const COPY_OPTIMIZATION: CopyOptimization<ViewRefControl, Self>
Sourcefn from_wire(wire: ViewRefControl) -> Self
fn from_wire(wire: ViewRefControl) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ViewRefControl
impl IntoNatural for ViewRefControl
Sourcetype Natural = ViewRefControl
type Natural = ViewRefControl
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ViewRefControl
impl Wire for ViewRefControl
Sourcetype Narrowed<'de> = ViewRefControl
type Narrowed<'de> = ViewRefControl
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.