#[repr(C)]pub struct ViewportCreationToken {
pub value: Channel,
}Expand description
The wire type corresponding to ViewportCreationToken.
Fields
value: ChannelTrait Implementations
Sourceimpl Constrained for ViewportCreationToken
impl Constrained for ViewportCreationToken
Sourceimpl Debug for ViewportCreationToken
impl Debug for ViewportCreationToken
Sourceimpl<___D> Decode<___D> for ViewportCreationTokenwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for ViewportCreationTokenwhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<ViewportCreationToken, ___E> for ViewportCreationTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ViewportCreationToken, ___E> for ViewportCreationTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ViewportCreationToken>
const COPY_OPTIMIZATION: CopyOptimization<Self, ViewportCreationToken>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewportCreationToken>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewportCreationToken>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ViewportCreationToken, ___E> for ViewportCreationToken<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Channel, ___E>,
impl<___E, T0> Encode<ViewportCreationToken, ___E> for ViewportCreationToken<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Channel, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewportCreationToken>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewportCreationToken>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ViewportCreationToken> for ViewportCreationToken
impl FromWire<ViewportCreationToken> for ViewportCreationToken
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ViewportCreationToken, Self>
const COPY_OPTIMIZATION: CopyOptimization<ViewportCreationToken, Self>
Sourcefn from_wire(wire: ViewportCreationToken) -> Self
fn from_wire(wire: ViewportCreationToken) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for ViewportCreationToken
impl IntoNatural for ViewportCreationToken
Sourcetype Natural = ViewportCreationToken
type Natural = ViewportCreationToken
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ViewportCreationToken
impl Wire for ViewportCreationToken
Sourcetype Narrowed<'de> = ViewportCreationToken
type Narrowed<'de> = ViewportCreationToken
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.