#[repr(C)]pub struct ViewportCreationToken {
pub value: Channel,
}Expand description
Two Flatland instances may be connected in a parent-child relationship. The parent endpoint is held in a Viewport.
ViewportCreationToken is a typed wrapper for a channel, representing the parent endpoint of the connection between two Flatlands. No messages will be sent over this channel, because it is only used as an unclonable object with peer.
Fields
value: ChannelTrait Implementations
Sourceimpl Debug for ViewportCreationToken
impl Debug for ViewportCreationToken
Sourceimpl<___E> Encode<ViewportCreationToken, ___E> for ViewportCreationTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<ViewportCreationToken, ___E> for ViewportCreationTokenwhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ViewportCreationToken>
const COPY_OPTIMIZATION: CopyOptimization<Self, ViewportCreationToken>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ViewportCreationToken>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ViewportCreationToken>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ViewportCreationToken>, ___E> for ViewportCreationToken
impl<___E> EncodeOption<Box<'static, ViewportCreationToken>, ___E> for ViewportCreationToken
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ViewportCreationToken>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ViewportCreationToken>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ViewportCreationToken> for ViewportCreationToken
impl FromWire<ViewportCreationToken> for ViewportCreationToken
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ViewportCreationToken, Self>
const COPY_OPTIMIZATION: CopyOptimization<ViewportCreationToken, Self>
Sourcefn from_wire(wire: ViewportCreationToken) -> Self
fn from_wire(wire: ViewportCreationToken) -> Self
Converts the given owned value to this type.
Sourceimpl PartialEq for ViewportCreationToken
impl PartialEq for ViewportCreationToken
impl StructuralPartialEq for ViewportCreationToken